@@ -18,6 +18,7 @@ import (
 	"testing"
 
 	orgv1 "github.com/eclipse/che-operator/pkg/apis/org/v1"
+	util "github.com/eclipse/che-operator/pkg/util"
 	"gopkg.in/yaml.v2"
 	appsv1 "k8s.io/api/apps/v1"
 )
@@ -58,8 +59,8 @@ func init() {
 				pvcJobsImageTest = env.Value
 			case "RELATED_IMAGE_postgres":
 				postgresImageTest = env.Value
-			case "RELATED_IMAGE_keycloak":
-				keycloakImageTest = env.Value
+			case util.GetArchitectureDependentEnv("RELATED_IMAGE_keycloak"):
+					keycloakImageTest = env.Value
 			case "RELATED_IMAGE_che_workspace_plugin_broker_metadata":
 				brokerMetadataTest = env.Value
 			case "RELATED_IMAGE_che_workspace_plugin_broker_artifacts":
@@ -106,6 +107,8 @@ func TestDefaultFromEnv(t *testing.T) {
 
 	if DefaultKeycloakImage(cheCluster) != keycloakImageTest {
 		t.Errorf("Expected %s but was %s", keycloakImageTest, DefaultKeycloakImage(cheCluster))
+	} else {
+		fmt.Printf("DEBUG s390x :: Expected keycloakImageTest = %s, and got DefaultKeycloakImage = %s", keycloakImageTest, DefaultKeycloakImage(cheCluster))
 	}
 
 	if DefaultCheWorkspacePluginBrokerMetadataImage(cheCluster) != brokerMetadataTest {
@@ -125,7 +128,7 @@ func TestCorrectImageName(t *testing.T) {
 	testCases := map[string]string{
 		"registry.redhat.io/codeready-workspaces/crw-2-rhel8-operator:latest":  "crw-2-rhel8-operator:latest",
 		"eclipse/che-operator:7.1.0":            "che-operator:7.1.0",
-		"registry.redhat.io/codeready-workspaces/crw-2-rhel8-operator:2.3":  "crw-2-rhel8-operator:2.3",
+		"registry.redhat.io/codeready-workspaces/crw-2-rhel8-operator:2.4":  "crw-2-rhel8-operator:2.4",
 	}
 	for k, v := range testCases {
 		t.Run(k, func(*testing.T) {
