@@ -56,7 +56,7 @@ var (
 	}
 )
 
-func SyncKeycloakDeploymentToCluster(checluster *orgv1.CheCluster, clusterAPI ClusterAPI) DeploymentProvisioningStatus {
+func SyncKeycloakDeploymentToCluster(checluster *orgv1.CheCluster, proxy *Proxy, clusterAPI ClusterAPI) DeploymentProvisioningStatus {
 	clusterDeployment, err := getClusterDeployment(KeycloakDeploymentName, checluster.Namespace, clusterAPI.Client)
 	if err != nil {
 		return DeploymentProvisioningStatus{
@@ -64,7 +64,7 @@ func SyncKeycloakDeploymentToCluster(checluster *orgv1.CheCluster, clusterAPI Cl
 		}
 	}
 
-	specDeployment, err := getSpecKeycloakDeployment(checluster, clusterDeployment, clusterAPI)
+	specDeployment, err := getSpecKeycloakDeployment(checluster, clusterDeployment, proxy, clusterAPI)
 	if err != nil {
 		return DeploymentProvisioningStatus{
 			ProvisioningStatus: ProvisioningStatus{Err: err},
@@ -74,7 +74,11 @@ func SyncKeycloakDeploymentToCluster(checluster *orgv1.CheCluster, clusterAPI Cl
 	return SyncDeploymentToCluster(checluster, specDeployment, clusterDeployment, keycloakCustomDiffOpts, keycloakAdditionalDeploymentMerge, clusterAPI)
 }
 
-func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *appsv1.Deployment, clusterAPI ClusterAPI) (*appsv1.Deployment, error) {
+func getSpecKeycloakDeployment(
+	checluster *orgv1.CheCluster,
+	clusterDeployment *appsv1.Deployment,
+	proxy *Proxy,
+	clusterAPI ClusterAPI) (*appsv1.Deployment, error) {
 	optionalEnv := true
 	labels := GetLabels(checluster, KeycloakDeploymentName)
 	cheFlavor := DefaultCheFlavor(checluster)
@@ -100,7 +104,6 @@ func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *
 	terminationGracePeriodSeconds := int64(30)
 	cheCertSecretVersion := getSecretResourceVersion("self-signed-certificate", checluster.Namespace, clusterAPI)
 	openshiftApiCertSecretVersion := getSecretResourceVersion("openshift-api-crt", checluster.Namespace, clusterAPI)
-	sslRequiredUpdatedForMasterRealm := isSslRequiredUpdatedForMasterRealm(checluster, clusterAPI)
 
 	// add various certificates to Java trust store so that Keycloak can connect to OpenShift API
 	// certificate that OpenShift router uses (for 4.0 only)
@@ -164,29 +167,29 @@ func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *
 	applyProxyCliCommand := ""
 	proxyEnvVars := []corev1.EnvVar{}
 
-	if len(checluster.Spec.Server.ProxyURL) > 1 {
-		proxySecret := checluster.Spec.Server.ProxySecret
-		cheWorkspaceHttpProxy, cheWorkspaceNoProxy, err := util.GenerateProxyEnvs(checluster.Spec.Server.ProxyURL, checluster.Spec.Server.ProxyPort, checluster.Spec.Server.NonProxyHosts, checluster.Spec.Server.ProxyUser, checluster.Spec.Server.ProxyPassword, proxySecret, checluster.Namespace)
-		if err != nil {
-			logrus.Errorf("Failed to read '%s' secret: %v", proxySecret, err)
-		}
-
+	if proxy.HttpProxy != "" {
 		proxyEnvVars = []corev1.EnvVar{
 			corev1.EnvVar{
 				Name:  "HTTP_PROXY",
-				Value: cheWorkspaceHttpProxy,
+				Value: proxy.HttpProxy,
 			},
 			corev1.EnvVar{
 				Name:  "HTTPS_PROXY",
-				Value: cheWorkspaceHttpProxy,
+				Value: proxy.HttpsProxy,
 			},
 			corev1.EnvVar{
 				Name:  "NO_PROXY",
-				Value: cheWorkspaceNoProxy,
+				Value: proxy.NoProxy,
 			},
 		}
 
-		cheWorkspaceNoProxy = strings.ReplaceAll(regexp.QuoteMeta(cheWorkspaceNoProxy), "\\", "\\\\\\")
+		quotedNoProxy := ""
+		for _, noProxyHost := range strings.Split(proxy.NoProxy, ",") {
+			if len(quotedNoProxy) != 0 {
+				quotedNoProxy += ","
+			}
+			quotedNoProxy += "\"" + strings.ReplaceAll(regexp.QuoteMeta(noProxyHost), "\\", "\\\\\\") + ";NO_PROXY\""
+		}
 
 		jbossCli := "/opt/jboss/keycloak/bin/jboss-cli.sh"
 		serverConfig := "standalone.xml"
@@ -196,7 +199,7 @@ func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *
 		}
 		addProxyCliCommand = " && echo Configuring Proxy && " +
 			"echo -e 'embed-server --server-config=" + serverConfig + " --std-out=echo \n" +
-			"/subsystem=keycloak-server/spi=connectionsHttpClient/provider=default:write-attribute(name=properties.proxy-mappings,value=[\"" + cheWorkspaceNoProxy + ";NO_PROXY\",\".*;" + cheWorkspaceHttpProxy + "\"]) \n" +
+			"/subsystem=keycloak-server/spi=connectionsHttpClient/provider=default:write-attribute(name=properties.proxy-mappings,value=[" + quotedNoProxy + ",\".*;" + proxy.HttpProxy + "\"]) \n" +
 			"stop-embedded-server' > " + jbossDir + "/setup-http-proxy.cli"
 
 		applyProxyCliCommand = " && " + jbossCli + " --file=" + jbossDir + "/setup-http-proxy.cli"
@@ -218,15 +221,19 @@ func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *
 		},
 		{
 			Name:  "POSTGRES_PORT_5432_TCP_ADDR",
-			Value: "postgres",
+			Value: util.GetValue(checluster.Spec.Database.ChePostgresHostName, DefaultChePostgresHostName),
 		},
 		{
 			Name:  "POSTGRES_PORT_5432_TCP_PORT",
-			Value: "5432",
+			Value: util.GetValue(checluster.Spec.Database.ChePostgresPort, DefaultChePostgresPort),
 		},
 		{
 			Name:  "POSTGRES_PORT",
-			Value: "5432",
+			Value: util.GetValue(checluster.Spec.Database.ChePostgresPort, DefaultChePostgresPort),
+		},
+		{
+			Name:  "POSTGRES_ADDR",
+			Value: util.GetValue(checluster.Spec.Database.ChePostgresHostName, DefaultChePostgresHostName),
 		},
 		{
 			Name:  "POSTGRES_DATABASE",
@@ -341,19 +348,19 @@ func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *
 			},
 			{
 				Name:  "KEYCLOAK_POSTGRESQL_SERVICE_HOST",
-				Value: "postgres",
+				Value: util.GetValue(checluster.Spec.Database.ChePostgresHostName, DefaultChePostgresHostName),
 			},
 			{
 				Name:  "KEYCLOAK_POSTGRESQL_SERVICE_PORT",
-				Value: "5432",
+				Value: util.GetValue(checluster.Spec.Database.ChePostgresPort, DefaultChePostgresPort),
 			},
 			{
 				Name:  "DB_DATABASE",
-				Value: KeycloakDeploymentName,
+				Value: "keycloak",
 			},
 			{
 				Name:  "DB_USERNAME",
-				Value: KeycloakDeploymentName,
+				Value: "keycloak",
 			},
 			{
 				Name:  "DB_VENDOR",
@@ -466,10 +473,12 @@ func getSpecKeycloakDeployment(checluster *orgv1.CheCluster, clusterDeployment *
 			" && sed -i 's/WILDCARD/ANY/g' /opt/eap/bin/launch/keycloak-spi.sh && /opt/eap/bin/openshift-launch.sh -b 0.0.0.0"
 	}
 
+	sslRequiredUpdatedForMasterRealm := isSslRequiredUpdatedForMasterRealm(checluster, clusterAPI)
 	if sslRequiredUpdatedForMasterRealm {
 		// update command to restart pod
 		command = "echo \"ssl_required WAS UPDATED for master realm.\" && " + command
 	}
+
 	args := []string{"-c", command}
 
 	deployment := &appsv1.Deployment{
@@ -577,6 +586,10 @@ func getSecretResourceVersion(name string, namespace string, clusterAPI ClusterA
 }
 
 func isSslRequiredUpdatedForMasterRealm(checluster *orgv1.CheCluster, clusterAPI ClusterAPI) bool {
+	if checluster.Spec.Database.ExternalDb {
+		return false
+	}
+
 	if util.IsTestMode() {
 		return false
 	}
@@ -616,16 +629,18 @@ func updateSslRequiredForMasterRealm(checluster *orgv1.CheCluster) error {
 }
 
 func ProvisionKeycloakResources(checluster *orgv1.CheCluster, clusterAPI ClusterAPI) error {
-	value, err := getSslRequiredForMasterRealm(checluster)
-	if err != nil {
-		return err
-	}
-
-	if value != "NONE" {
-		err := updateSslRequiredForMasterRealm(checluster)
+	if !checluster.Spec.Database.ExternalDb {
+		value, err := getSslRequiredForMasterRealm(checluster)
 		if err != nil {
 			return err
 		}
+
+		if value != "NONE" {
+			err := updateSslRequiredForMasterRealm(checluster)
+			if err != nil {
+				return err
+			}
+		}
 	}
 
 	keycloakProvisionCommand := GetKeycloakProvisionCommand(checluster)
